<?php
/*
 * Copyright (C) TIPS4DESIGN SRL - All Rights Reserved
 * Unauthorized copying of this file or any parts of it, via any medium is strictly prohibited
 * Only a valid UXWizz license holder should have access to this file
 * Proprietary and confidential
 * Written by Cristian Buleandră <cristian@uxwizz.com>, Fri 17 November 2023
 */

require_once __DIR__ . '/../../login.php';
require_once __DIR__ . '/../../permissions.php';
try {
    checkPermission('CHAT_WITH_AI');
} catch (Exception $e) {
    die($e->getMessage());
}

require_once __DIR__ . '/prompt/system/default.php';

$api_key = $db->query("SELECT value FROM `ust_meta` WHERE `key`='CHATBOT_SETTING_OPENAI_KEY'")->fetch(PDO::FETCH_COLUMN);
if (!$api_key) {
    die('OpenAI ChatGPT API Key not set.');
}
$api_url = 'https://api.openai.com/v1/chat/completions';

// Define the prompt
$prompt = $_POST['question'];
$domain = $_POST['domain'];

// Make sure user has access to domain
$stmt = $db->prepare("SELECT COUNT(*) FROM ust_access WHERE userid = :userID AND domain = :domain");
$stmt->bindValue(':userID', $userId, PDO::PARAM_STR);
$stmt->bindValue(':domain', $domain, PDO::PARAM_STR);
$stmt->execute();

$userHasAccessToDomain = $stmt->fetchColumn();
if (!$userHasAccessToDomain) {
    die('You do not have access to query data for this domain.');
}

require_once __DIR__ . '/getAIModel.php';
$model = getAIModel();

// Set up the data for the API request
$data = [
    'model' => $model,
    'response_format' => ["type" => "json_object"],
    'messages' => [
        ['role' => 'system', 'content' => $UXW_SYSTEM_PROMPT],
        ['role' => 'user', 'content' => $prompt . '. Domain: ' . $domain],
    ],
];

$options = [
    'http' => [
        'header' => "Content-Type: application/json\r\n" .
            "Authorization: Bearer $api_key\r\n",
        'method' => 'POST',
        'method' => 'POST',
        'content' => json_encode($data),
        'ignore_errors' => true, // Handle errors manually
    ],
];

$context = stream_context_create($options);

// Make the API request
$response = file_get_contents($api_url, false, $context);

// Check for errors
if ($response === FALSE) {
    die('Error occurred while fetching data from ChatGPT API');
}
echo $response;


try {
    // Security:
    // Cache the last response, so when we execute the query the user can not pass in any string
    $decoded_response = json_decode($response, true);
    $_SESSION['UXW_CHAT_LAST_RESPONSE'] = $decoded_response['choices'][0]['message']['content'];
} catch (Exception $e) {
    error_log($e);
}
